commit-gnuradio
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Commit-gnuradio] r7179 - usrp2/trunk/firmware/apps


From: eb
Subject: [Commit-gnuradio] r7179 - usrp2/trunk/firmware/apps
Date: Fri, 14 Dec 2007 12:08:54 -0700 (MST)

Author: eb
Date: 2007-12-14 12:08:54 -0700 (Fri, 14 Dec 2007)
New Revision: 7179

Modified:
   usrp2/trunk/firmware/apps/rx_only.c
Log:
when simulating, trigger start_rx_cmd

Modified: usrp2/trunk/firmware/apps/rx_only.c
===================================================================
--- usrp2/trunk/firmware/apps/rx_only.c 2007-12-14 18:39:04 UTC (rev 7178)
+++ usrp2/trunk/firmware/apps/rx_only.c 2007-12-14 19:08:54 UTC (rev 7179)
@@ -333,9 +333,11 @@
   // setup receive from ETH
   bp_receive_to_buf(CPU_RX_BUF, PORT_ETH, 1, 0, 255);
 
-  // FIXME fake that we got a start command
-  // u2_mac_addr_t host = {{ 0x00, 0x0A, 0xE4, 0x3E, 0xD2, 0xD5 }};
-  // start_rx_cmd(&host);
+  if (hwconfig_simulation_p()){
+    // If we're simulating, pretend that we got a start command from the host
+    u2_mac_addr_t host = {{ 0x00, 0x0A, 0xE4, 0x3E, 0xD2, 0xD5 }};
+    start_rx_cmd(&host);
+  }
 
   while(1){
     // FIXME perhaps handle low-pri stuff here





reply via email to

[Prev in Thread] Current Thread [Next in Thread]